import React from 'react';
import { Link } from 'react-router-dom';

const About = () => {
  return (
    <div className="bg-dark-900 text-white">
      {/* Hero Section */}
      <section className="py-20 bg-gradient-to-b from-dark-800 to-dark-900">
        <div className="container mx-auto px-6">
          <div className="text-center max-w-3xl mx-auto">
            <h1 className="text-4xl md:text-5xl font-bold mb-6">Our Mission</h1>
            <p className="text-xl text-gray-300 leading-relaxed mb-8">
              DoTechBro is dedicated to empowering minorities, particularly African Americans, to 
              successfully transition into the tech industry and thrive in their careers.
            </p>
          </div>
        </div>
      </section>

      {/* Vision Section */}
      <section className="py-16 bg-dark-800">
        <div className="container mx-auto px-6">
          <div className="grid grid-cols-1 md:grid-cols-2 gap-12 items-center">
            <div>
              <h2 className="text-3xl font-bold mb-6 bg-gradient-to-r from-primary-500 to-secondary-500 bg-clip-text text-transparent">Our Vision</h2>
              <p className="text-gray-300 mb-6 leading-relaxed">
                We envision a tech industry that reflects the diversity of our society, where 
                minorities have equal opportunities to innovate, lead, and succeed. Our goal is to 
                bridge the gap by providing targeted resources, mentorship, and community support.
              </p>
              <p className="text-gray-300 leading-relaxed">
                By creating comprehensive roadmaps, curating high-quality learning materials, and 
                fostering a supportive community, we aim to give underrepresented individuals the 
                confidence and skills needed to thrive in technology careers.
              </p>
            </div>
            <div className="bg-dark-700 p-8 rounded-xl shadow-lg">
              <h3 className="text-2xl font-bold mb-4">Why We Started</h3>
              <p className="text-gray-300 mb-4">
                The tech industry has a well-documented diversity problem. Despite making up 13.4% of the 
                U.S. population, Black Americans represent only about 7% of the computing workforce. 
                We believe this isn't due to lack of talent or interest, but rather barriers to entry and lack of tailored resources.
              </p>
              <p className="text-gray-300">
                DoTechBro was created to address these challenges head-on by providing clear pathways
                into tech that acknowledge and overcome the unique obstacles minorities face.
              </p>
            </div>
          </div>
        </div>
      </section>

      {/* What We Do Section */}
      <section className="py-16 bg-gradient-to-b from-dark-900 to-dark-800">
        <div className="container mx-auto px-6">
          <h2 className="text-3xl font-bold text-center mb-12">What We Do</h2>
          
          <div className="grid grid-cols-1 md:grid-cols-3 gap-8">
            <div className="bg-dark-700 rounded-xl p-8 shadow-lg hover:shadow-xl transition-shadow duration-300">
              <div className="text-primary-500 text-3xl mb-4">
                <svg xmlns="http://www.w3.org/2000/svg" className="h-12 w-12" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M9 19v-6a2 2 0 00-2-2H5a2 2 0 00-2 2v6a2 2 0 002 2h2a2 2 0 002-2zm0 0V9a2 2 0 012-2h2a2 2 0 012 2v10m-6 0a2 2 0 002 2h2a2 2 0 002-2m0 0V5a2 2 0 012-2h2a2 2 0 012 2v14a2 2 0 01-2 2h-2a2 2 0 01-2-2z" />
                </svg>
              </div>
              <h3 className="text-xl font-bold mb-3">Career Roadmaps</h3>
              <p className="text-gray-300">
                We create tailored roadmaps for various tech career paths, breaking down complex journeys into manageable steps with 
                clear guidance and resources for each stage.
              </p>
            </div>
            
            <div className="bg-dark-700 rounded-xl p-8 shadow-lg hover:shadow-xl transition-shadow duration-300">
              <div className="text-primary-500 text-3xl mb-4">
                <svg xmlns="http://www.w3.org/2000/svg" className="h-12 w-12" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M12 6.253v13m0-13C10.832 5.477 9.246 5 7.5 5S4.168 5.477 3 6.253v13C4.168 18.477 5.754 18 7.5 18s3.332.477 4.5 1.253m0-13C13.168 5.477 14.754 5 16.5 5c1.747 0 3.332.477 4.5 1.253v13C19.832 18.477 18.247 18 16.5 18c-1.746 0-3.332.477-4.5 1.253" />
                </svg>
              </div>
              <h3 className="text-xl font-bold mb-3">Resource Curation</h3>
              <p className="text-gray-300">
                We curate high-quality learning resources, from tutorials to practice projects, saving you time and helping you 
                focus on what actually works to build your skills.
              </p>
            </div>
            
            <div className="bg-dark-700 rounded-xl p-8 shadow-lg hover:shadow-xl transition-shadow duration-300">
              <div className="text-primary-500 text-3xl mb-4">
                <svg xmlns="http://www.w3.org/2000/svg" className="h-12 w-12" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M17 20h5v-2a3 3 0 00-5.356-1.857M17 20H7m10 0v-2c0-.656-.126-1.283-.356-1.857M7 20H2v-2a3 3 0 015.356-1.857M7 20v-2c0-.656.126-1.283.356-1.857m0 0a5.002 5.002 0 019.288 0M15 7a3 3 0 11-6 0 3 3 0 016 0zm6 3a2 2 0 11-4 0 2 2 0 014 0zM7 10a2 2 0 11-4 0 2 2 0 014 0z" />
                </svg>
              </div>
              <h3 className="text-xl font-bold mb-3">Community Building</h3>
              <p className="text-gray-300">
                We're building a supportive community where you can connect with others on similar journeys, 
                share experiences, and get guidance from those who've succeeded.
              </p>
            </div>
          </div>
        </div>
      </section>

      {/* Values */}
      <section className="py-16 bg-dark-800">
        <div className="container mx-auto px-6">
          <h2 className="text-3xl font-bold text-center mb-6">Our Values</h2>
          <p className="text-center text-gray-300 max-w-3xl mx-auto mb-12">
            These core principles guide everything we do at DoTechBro and shape how we serve our community.
          </p>
          
          <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
            <div className="bg-dark-700 rounded-lg p-6 border-l-4 border-primary-500">
              <h3 className="text-xl font-bold mb-2">Accessibility</h3>
              <p className="text-gray-300">
                We believe tech education should be accessible to everyone, regardless of background or prior experience.
              </p>
            </div>
            
            <div className="bg-dark-700 rounded-lg p-6 border-l-4 border-primary-500">
              <h3 className="text-xl font-bold mb-2">Authenticity</h3>
              <p className="text-gray-300">
                We keep it real about the challenges of breaking into tech while providing actionable solutions.
              </p>
            </div>
            
            <div className="bg-dark-700 rounded-lg p-6 border-l-4 border-primary-500">
              <h3 className="text-xl font-bold mb-2">Community</h3>
              <p className="text-gray-300">
                We believe in the power of community to overcome obstacles and accelerate growth.
              </p>
            </div>
            
            <div className="bg-dark-700 rounded-lg p-6 border-l-4 border-primary-500">
              <h3 className="text-xl font-bold mb-2">Excellence</h3>
              <p className="text-gray-300">
                We're committed to providing high-quality resources that actually prepare you for success in the industry.
              </p>
            </div>
          </div>
        </div>
      </section>

      {/* Call to Action */}
      <section className="py-20 bg-gradient-to-b from-dark-800 to-dark-900">
        <div className="container mx-auto px-6 text-center">
          <h2 className="text-3xl font-bold mb-6">Ready to Start Your Tech Journey?</h2>
          <p className="text-xl text-gray-300 mb-8 max-w-2xl mx-auto">
            Join our community today and take the first step toward your career in tech.
          </p>
          <div className="flex flex-wrap justify-center gap-4">
            <Link 
              to="/roadmap" 
              className="px-8 py-3 bg-primary-600 hover:bg-primary-700 text-white rounded-lg shadow-lg transition-colors"
            >
              Explore Roadmaps
            </Link>
            <Link 
              to="/" 
              className="px-8 py-3 border-2 border-primary-500 text-primary-400 hover:bg-primary-500/10 rounded-lg transition-colors"
            >
              Join Our Community
            </Link>
          </div>
        </div>
      </section>
    </div>
  );
};

export default About;