import { useState } from 'react';
import { Link } from 'react-router-dom';
import './Header.css'; // Import the custom CSS file

const Header = ({ onMenuToggle }) => {
  const [isOpen, setIsOpen] = useState(false);

  const toggleMenu = () => {
    setIsOpen(!isOpen);
    if (onMenuToggle) onMenuToggle(!isOpen);
  };

  return (
    <header className="bg-dark-800 text-white py-4 px-6 flex justify-between items-center relative shadow-md">
      <div className="flex items-center">
        <Link 
          to="/" 
          className="text-2xl font-bold bg-gradient-to-r from-primary-500 to-secondary-500 bg-clip-text text-transparent hover:opacity-90 transition-opacity duration-300"
        >
          DoTechBro.org
        </Link>
      </div>
      
      <div className="md:hidden">
        <button 
          onClick={toggleMenu} 
          className="p-2 rounded-md hover:bg-dark-700 focus:outline-none focus:ring-2 focus:ring-primary-500 transition-colors"
          aria-label={isOpen ? "Close menu" : "Open menu"}
          aria-expanded={isOpen}
        >
          <svg className="w-6 h-6" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
            <path strokeLinecap="round" strokeLinejoin="round" strokeWidth="2" d={isOpen ? "M6 18L18 6M6 6l12 12" : "M4 6h16M4 12h16m-7 6h7"}></path>
          </svg>
        </button>
      </div>
      
      <nav className="hidden md:flex md:items-center md:space-x-8">
        <Link to="/" className="link-underline text-white hover:text-primary-400 transition-colors">Home</Link>
        <Link to="/about" className="link-underline text-white hover:text-primary-400 transition-colors">About</Link>
        <Link to="/roadmap" className="link-underline text-white hover:text-primary-400 transition-colors">Roadmaps</Link>
        <Link to="/roadmap" className="ml-4 bg-primary-600 hover:bg-primary-700 text-white py-2 px-4 rounded-lg transition-colors shadow-sm">Get Started</Link>
      </nav>
      
      {isOpen && (
        <div className="absolute top-full left-0 w-full bg-dark-800 text-white shadow-lg rounded-b-lg z-50 md:hidden animate-dropdown">
          <div className="flex flex-col py-3 px-6 space-y-4">
            <Link to="/" className="py-2 link-underline text-white hover:text-primary-400 transition-colors" onClick={toggleMenu}>Home</Link>
            <Link to="/about" className="py-2 link-underline text-white hover:text-primary-400 transition-colors" onClick={toggleMenu}>About</Link>
            <Link to="/roadmap" className="py-2 link-underline text-white hover:text-primary-400 transition-colors" onClick={toggleMenu}>Roadmaps</Link>
            <Link to="/roadmap" className="bg-primary-600 hover:bg-primary-700 text-white py-2 px-4 rounded-lg text-center transition-colors shadow-sm" onClick={toggleMenu}>Get Started</Link>
          </div>
        </div>
      )}
    </header>
  );
};

export default Header;