import { Outlet, useLocation, Link } from 'react-router-dom';
import challenges from '../challenges';
import roadmaps from '../roadmaps.json';
import Accordion from './Accordion';

const Roadmap = () => {
  const location = useLocation();
  const isRootPath = location.pathname === '/roadmap';

  return (
    <div className="bg-dark-900 text-white min-h-screen">
      {isRootPath ? (
        <>
          {/* Hero Section */}
          <section className="py-16 md:py-24 bg-gradient-to-b from-dark-800 to-dark-900">
            <div className="container mx-auto px-6">
              <div className="max-w-3xl mx-auto text-center">
                <h1 className="text-4xl md:text-5xl font-bold mb-6">Tech Career Roadmaps</h1>
                <p className="text-xl text-gray-300 leading-relaxed mb-8">
                  Structured pathways to help you navigate your journey into tech, with step-by-step guidance 
                  and curated resources tailored for minorities entering the industry.
                </p>
                <div className="inline-flex items-center justify-center p-1 rounded-lg bg-gradient-to-r from-primary-500 to-secondary-500">
                  <a href="#roadmaps" className="bg-dark-800 text-white font-medium px-6 py-3 rounded-md hover:bg-dark-700 transition-colors">
                    Explore Roadmaps
                  </a>
                </div>
              </div>
            </div>
          </section>

          {/* Challenges Section */}
          <section className="py-16 bg-dark-800" id="challenges">
            <div className="container mx-auto px-6">
              <div className="max-w-3xl mx-auto">
                <h2 className="text-3xl font-bold mb-8 text-center">Common Challenges</h2>
                <p className="text-lg text-gray-300 text-center mb-12">
                  We understand the unique obstacles minorities face when entering tech. 
                  Here's how our roadmaps address these challenges.
                </p>
                <Accordion items={challenges} />
              </div>
            </div>
          </section>

          {/* Roadmaps Section */}
          <section className="py-16 bg-gradient-to-b from-dark-900 to-dark-800" id="roadmaps">
            <div className="container mx-auto px-6">
              <h2 className="text-3xl font-bold text-center mb-6">Available Roadmaps</h2>
              <p className="text-lg text-gray-300 text-center max-w-3xl mx-auto mb-12">
                Select a roadmap that aligns with your interests and goals. Each provides a clear path 
                from beginner to professional.
              </p>
              
              <div className="grid grid-cols-1 md:grid-cols-3 gap-8">
                {roadmaps.map((roadmap, index) => (
                  <Link 
                    key={index} 
                    to={`/roadmap/${roadmap.id}`} 
                    className="group bg-dark-700 rounded-xl overflow-hidden shadow-lg hover:shadow-xl transition-all duration-300 flex flex-col h-full"
                  >
                    <div className="p-1 bg-gradient-to-r from-primary-500 to-secondary-500">
                      <div className="bg-dark-700 p-6 flex-grow">
                        <h3 className="text-2xl font-bold mb-4 group-hover:text-primary-400 transition-colors">
                          {roadmap.title}
                        </h3>
                        <p className="text-gray-300 mb-6">{roadmap.description}</p>
                        <div className="flex flex-wrap gap-2 mb-4">
                          {['Beginner-Friendly', 'Step-by-Step', 'Resource Links'].map((tag, i) => (
                            <span key={i} className="text-xs bg-dark-600 text-gray-300 px-2 py-1 rounded-full">
                              {tag}
                            </span>
                          ))}
                        </div>
                      </div>
                    </div>
                    <div className="p-4 bg-dark-600 text-primary-400 font-medium flex justify-between items-center">
                      <span>View Roadmap</span>
                      <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5 transform group-hover:translate-x-1 transition-transform" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                        <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M14 5l7 7m0 0l-7 7m7-7H3" />
                      </svg>
                    </div>
                  </Link>
                ))}
              </div>
            </div>
          </section>

          {/* Coming Soon Section */}
          <section className="py-16 bg-dark-800">
            <div className="container mx-auto px-6">
              <div className="bg-gradient-to-r from-dark-700 to-dark-600 rounded-xl p-8 max-w-4xl mx-auto">
                <h3 className="text-2xl font-bold mb-4 text-center">More Roadmaps Coming Soon</h3>
                <div className="flex flex-col md:flex-row items-center gap-8">
                  <div className="md:w-3/4">
                    <p className="text-gray-300 mb-4">
                      We're actively developing additional roadmaps for various tech roles including:
                    </p>
                    <ul className="list-disc list-inside text-gray-300 mb-4 space-y-2">
                      <li>Cloud Engineering</li>
                      <li>Machine Learning & AI</li>
                      <li>Product Management</li>
                      <li>Cybersecurity</li>
                      <li>Mobile App Development</li>
                    </ul>
                    <p className="text-gray-300">
                      Subscribe to our newsletter to get notified when new roadmaps are released.
                    </p>
                  </div>
                  <div className="md:w-1/4 flex justify-center">
                    <div className="w-24 h-24 rounded-full bg-dark-500 flex items-center justify-center">
                      <svg xmlns="http://www.w3.org/2000/svg" className="h-12 w-12 text-primary-500" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                        <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M12 6v6m0 0v6m0-6h6m-6 0H6" />
                      </svg>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </section>

          {/* Contribute Section */}
          <section className="py-16 bg-gradient-to-b from-dark-800 to-dark-900">
            <div className="container mx-auto px-6 text-center">
              <h3 className="text-3xl font-bold mb-6">Open Source Collaboration</h3>
              <p className="text-lg text-gray-300 mb-8 max-w-2xl mx-auto">
                These roadmaps are open source and we welcome contributions from the community. 
                Help us improve these resources for everyone.
              </p>
              <div className="inline-block bg-gradient-to-r from-primary-500 to-secondary-500 p-0.5 rounded-lg">
                <button className="px-8 py-3 bg-dark-800 hover:bg-dark-700 text-white font-medium rounded-md transition-colors">
                  Contribute on GitHub
                </button>
              </div>
            </div>
          </section>
        </>
      ) : (
        <Outlet />
      )}
    </div>
  );
};

export default Roadmap;